==> nlpiper-0.2.1.tar.gz: nlpiper-0.2.1/nlpiper/transformers/tokenizers.py <==
"""Tokenizer Module."""

from typing import Optional
from nlpiper.core.document import (
    Document,
    Token
)
from nlpiper.logger import log
from nlpiper.transformers.base import (
    BaseTransformer,
    TransformersType,
    add_step,
    validate
)


__all__ = [
    "BasicTokenizer",
    "MosesTokenizer",
    "StanzaTokenizer"
]


class BasicTokenizer(BaseTransformer):
    """Basic tokenizer which tokenizes a document by splitting tokens by its blank spaces."""

    @validate(TransformersType.TOKENIZERS)
    @add_step
    def __call__(self, doc: Document, inplace: bool = False) -> Optional[Document]:
        """Tokenize the document in a list of tokens.

        Args:
            doc (Document): Text to be tokenized.
            inplace (bool): if False will return a new doc object,
                            otherwise will change the object passed as parameter.

        Returns: Document
        """
        d = doc if inplace else doc._deepcopy()

        d.tokens = [Token(token) for token in d.cleaned.split()]

        return None if inplace else d


class MosesTokenizer(BaseTransformer):
    """SacreMoses tokenizer.

    Transformer to tokenize a Document using Sacremoses, https://github.com/alvations/sacremoses
    """

    def __init__(self, *args, **kwargs):
        """SacreMoses tokenizer.

        Args:
            *args: See the docs at https://github.com/alvations/sacremoses for more information.
            **kwargs: See the docs at https://github.com/alvations/sacremoses for more information.
        """
        super().__init__(*args, **kwargs)
        try:
            from sacremoses import MosesTokenizer
            self.t = MosesTokenizer(*args, **kwargs)

        except ImportError:
            log.error("Please install SacreMoses. "
                      "See the docs at https://github.com/alvations/sacremoses for more information.")
            raise

    @validate(TransformersType.TOKENIZERS)
    @add_step
    def __call__(self, doc: Document, inplace: bool = False) -> Optional[Document]:
        """Tokenize the document in a list of tokens.

        Args:
            doc (Document): Document to be tokenized.
            inplace (bool): if False will return a new doc object,
                            otherwise will change the object passed as parameter.

        Returns: Document
        """
        d = doc if inplace else doc._deepcopy()

        d.tokens = [Token(token) for token in self.t.tokenize(d.cleaned)]

        return None if inplace else d


class StanzaTokenizer(BaseTransformer):
    """Stanza tokenizer.

    Transformer to tokenize a Document using stanza, https://github.com/stanfordnlp/stanza
    """

    def __init__(self, language: str = 'en', processors='tokenize', *args, **kwargs):
        """Stanza tokenizer.

        Args:
            language (str): document main language.
            *args: See the docs at https://stanfordnlp.github.io/stanza/tokenize.html add for more information.
            **kwargs: See the docs at https://stanfordnlp.github.io/stanza/tokenize.html add for more information.
        """
        super().__init__(language=language, processors=processors, *args, **kwargs)
        try:
            import stanza
            from stanza import Pipeline
            stanza.download(language)
            assert 'tokenize' in processors.lower(), 'StanzaTokenizer needs `"tokenize"` on processors'
            self.p = Pipeline(lang=language, processors=processors, tokenize_pretokenized=False, *args,
                              **kwargs)
            self.processors = processors

        except ImportError:
            log.error("Please install Stanza. "
                      "See the docs at https://github.com/stanfordnlp/stanza for more information.")
            raise

    @validate(TransformersType.TOKENIZERS)
    @add_step
    def __call__(self, doc: Document, inplace: bool = False) -> Optional[Document]:
        """Tokenize the document in a list of tokens.

        Args:
            doc (Document): Document to be tokenized.
            inplace (bool): if False will return a new doc object,
                            otherwise will change the object passed as parameter.

        Returns: Document
        """
        d = doc if inplace else doc._deepcopy()

        tokens = []
        for sentence in self.p(doc.cleaned).sentences:
            for word in sentence.words:
                token = Token(word.parent.text)

                if 'lemma' in self.processors.lower():
                    token.lemma = word.lemma

                if 'ner' in self.processors.lower():
                    token.ner = word.parent.ner

                tokens.append(token)
        d.tokens = tokens

        return None if inplace else d

==> nlpiper-0.3.0.tar.gz: nlpiper-0.3.0/nlpiper/transformers/tokenizers.py <==
"""Tokenizer Module."""

from typing import Optional
from nlpiper.core.document import (
    Document,
    Token
)
from nlpiper.logger import log
from nlpiper.transformers.base import (
    BaseTransformer,
    TransformersType,
    add_step,
    validate
)


__all__ = [
    "BasicTokenizer",
    "MosesTokenizer",
    "StanzaTokenizer"
]


class BasicTokenizer(BaseTransformer):
    """Basic tokenizer which tokenizes a document by splitting tokens by its blank spaces."""

    @validate(TransformersType.TOKENIZERS)
    @add_step
    def __call__(self, doc: Document, inplace: bool = False) -> Optional[Document]:
        """Tokenize the document in a list of tokens.

        Args:
            doc (Document): Text to be tokenized.
            inplace (bool): if False will return a new doc object,
                            otherwise will change the object passed as parameter.

        Returns: Document
        """
        d = doc if inplace else doc._deepcopy()

        d.tokens = [Token(token) for token in d.cleaned.split()]

        return None if inplace else d


class MosesTokenizer(BaseTransformer):
    """SacreMoses tokenizer.

    Transformer to tokenize a Document using Sacremoses, https://github.com/alvations/sacremoses
    """

    def __init__(self, *args, **kwargs):
        """SacreMoses tokenizer.

        Args:
            *args: See the docs at https://github.com/alvations/sacremoses for more information.
            **kwargs: See the docs at https://github.com/alvations/sacremoses for more information.
        """
        super().__init__(*args, **kwargs)
        try:
            from sacremoses import MosesTokenizer
            self.t = MosesTokenizer(*args, **kwargs)

        except ImportError:
            log.error("Please install SacreMoses. "
                      "See the docs at https://github.com/alvations/sacremoses for more information.")
            raise

    @validate(TransformersType.TOKENIZERS)
    @add_step
    def __call__(self, doc: Document, inplace: bool = False) -> Optional[Document]:
        """Tokenize the document in a list of tokens.

        Args:
            doc (Document): Document to be tokenized.
            inplace (bool): if False will return a new doc object,
                            otherwise will change the object passed as parameter.

        Returns: Document
        """
        d = doc if inplace else doc._deepcopy()

        d.tokens = [Token(token) for token in self.t.tokenize(d.cleaned)]

        return None if inplace else d


class StanzaTokenizer(BaseTransformer):
    """Stanza tokenizer.

    Transformer to tokenize a Document using stanza, https://github.com/stanfordnlp/stanza
    """

    def __init__(self, language: str = 'en', processors='tokenize', *args, **kwargs):
        """Stanza tokenizer.

        Args:
            language (str): document main language.
            *args: See the docs at https://stanfordnlp.github.io/stanza/tokenize.html add for more information.
            **kwargs: See the docs at https://stanfordnlp.github.io/stanza/tokenize.html add for more information.
        """
        super().__init__(language=language, processors=processors, *args, **kwargs)
        try:
            import stanza
            from stanza import Pipeline
            stanza.download(language)
            assert 'tokenize' in processors.lower(), 'StanzaTokenizer needs `"tokenize"` on processors'
            self.p = Pipeline(lang=language, processors=processors, tokenize_pretokenized=False, *args,
                              **kwargs)
            self.processors = processors

        except ImportError:
            log.error("Please install Stanza. "
                      "See the docs at https://github.com/stanfordnlp/stanza for more information.")
            raise

    @validate(TransformersType.TOKENIZERS)
    @add_step
    def __call__(self, doc: Document, inplace: bool = False) -> Optional[Document]:
        """Tokenize the document in a list of tokens.

        Args:
            doc (Document): Document to be tokenized.
            inplace (bool): if False will return a new doc object,
                            otherwise will change the object passed as parameter.

        Returns: Document
        """
        d = doc if inplace else doc._deepcopy()

        tokens = []
        for sentence in self.p(doc.cleaned).sentences:
            for word in sentence.words:
                token = Token(word.parent.text)

                if 'lemma' in self.processors.lower():
                    token.lemma = word.lemma

                if 'ner' in self.processors.lower():
                    token.ner = word.parent.ner

                tokens.append(token)
        d.tokens = tokens

        return None if inplace else d


class SpacyTokenizer(BaseTransformer):
    """Spacy tokenizer.

    Transformer to tokenize a Document using spacy, https://spacy.io

    Callable arguments:

    Args:
        doc (Document): Document to be tokenized.
        inplace (bool, default False): if False will return a new document object,
                        otherwise will change the object passed as parameter and return None.

    Returns:
        Document and respective Tokens or None if `inplace=True`.

    Example:
        >>> from nlpiper.core import Document
        >>> doc = Document("NLPiper is fun.")
        >>> tokenizer = SpacyTokenizer()
        >>> out = tokenizer(doc)
        >>> out.tokens
        [Token(original='NLPiper', cleaned='NLPiper', lemma='nlpiper', stem=None, ner='ORG', embedded=None, ner_iob='B', tag='NN'), Token(original='is', cleaned='is', lemma='be', stem=None, ner='', embedded=None, ner_iob='O', tag='VBZ'), Token(original='fun', cleaned='fun', lemma='fun', stem=None, ner='', embedded=None, ner_iob='O', tag='JJ'), Token(original='.', cleaned='.', lemma='.', stem=None, ner='', embedded=None, ner_iob='O', tag='.')]
    """  # noqa: E501
    def __init__(self, name: str = 'en_core_web_sm', *args, **kwargs):
        """Spacy tokenizer.

        Args:
            name (str): Package name or model path.
        """
        super().__init__(name=name, *args, **kwargs)
        try:
            import spacy
            self.nlp = spacy.load(name, *args, **kwargs)

        except ImportError:
            log.error("Please install Spacy. "
                      "See the docs at https://spacy.io/usage for more information.")
            raise

    @validate(TransformersType.TOKENIZERS)
    @add_step
    def __call__(self, doc: Document, inplace: bool = False) -> Optional[Document]:
        """Tokenize the document in a list of tokens.

        Args:
            doc (Document): Document to be tokenized.
            inplace (bool, default False): if False will return a new document object,
                        otherwise will change the object passed as parameter and return None.

        Returns: Document
        """
        d = doc if inplace else doc._deepcopy()

        tokens = []
        for t in self.nlp(doc.cleaned):
            token = Token(t.text)

            token.lemma = t.lemma_
            token.ner = t.ent_type_
            token.ner_iob = t.ent_iob_  # type: ignore
            token.tag = t.tag_  # type: ignore

            tokens.append(token)
        d.tokens = tokens

        return None if inplace else d
